@@ -21,11 +21,11 @@ class AboutDialog : public QDialog
 	Q_OBJECT
 
 public:
-	AboutDialog(QWidget *parent = 0);
+	AboutDialog(QWidget *parent = 0); ///< set-up about dialog
 	~AboutDialog();
 	Ui::AboutDialog ui;
 private slots:
-	void largeLogo();
+	void largeLogo(); ///< show enlarged logo, triggered via context menu on image in about-dialog
 };
 
 
