@@ -23,7 +23,9 @@ static const QString DEPRECACTED_TMX_INTERNAL_PDF_VIEWER = "tmx://internal-pdf-v
 const QString BuildManager::TXS_CMD_PREFIX = "txs:///";
 
 int BuildManager::autoRerunLatex = 5;
+bool BuildManager::showLogInCaseOfCompileError = true;
 bool BuildManager::m_replaceEnvironmentVariables = true;
+bool BuildManager::m_interpetCommandDefinitionInMagicComment = true;
 bool BuildManager::m_supportShellStyleLiteralQuotes = true;
 bool BuildManager::singleViewerInstance = false;
 QString BuildManager::autoRerunCommands;
@@ -40,6 +42,10 @@ CMD_DEFINE(INTERNAL_PRE_COMPILE, internal-pre-compile)
 #undef CMD_DEFINE
 // *INDENT-ON* (astyle-config)
 
+//! These commands should not consist of a command list, but rather a single command.
+//! Otherwise surpising side effects can happen, see https://sourceforge.net/p/texstudio/bugs/2119/
+const QStringList atomicCommands = QStringList() << "txs:///latex" << "txs:///pdflatex" << "txs:///xelatex"<< "txs:///lualatex" << "txs:///latexmk";
+
 QString searchBaseCommand(const QString &cmd, QString options);
 QString getCommandLineViewDvi();
 QString getCommandLineViewPs();
@@ -311,8 +317,8 @@ void BuildManager::initDefaultCommandNames()
 	descriptionList << tr("PdfLaTeX") << tr("LaTeX") << tr("XeLaTeX") << tr("LuaLaTeX") << tr("Latexmk");
 	registerCommand("compile", tr("Default Compiler"), QStringList() << "txs:///pdflatex" << "txs:///latex" << "txs:///xelatex" << "txs:///lualatex" << "txs:///latexmk", "", true, descriptionList);
 	descriptionList.clear();
-	descriptionList << tr("PDF Viewer") << tr("DVI Viewer") << tr("PS Viewer") << tr("Internal PDF Viewer (Windowed)") << tr("Internal PDF Viewer (Embedded)") << tr("External PDF Viewer");
-	registerCommand("view", tr("Default Viewer"), QStringList() << "txs:///view-pdf" << "txs:///view-dvi" << "txs:///view-ps" << "txs:///view-pdf-internal" << "txs:///view-pdf-internal --embedded" << "txs:///view-pdf-external", "", true, descriptionList);
+	descriptionList << tr("PDF Viewer") << tr("DVI Viewer") << tr("PS Viewer");
+	registerCommand("view", tr("Default Viewer"), QStringList() << "txs:///view-pdf" << "txs:///view-dvi" << "txs:///view-ps", "", true, descriptionList);
 	descriptionList.clear();
 	descriptionList << tr("Internal PDF Viewer (Embedded)") << tr("Internal PDF Viewer (Windowed)")  << tr("External PDF Viewer");
 	registerCommand("view-pdf", tr("PDF Viewer"), QStringList() << "txs:///view-pdf-internal --embedded" << "txs:///view-pdf-internal" << "txs:///view-pdf-external", "", true, descriptionList);
@@ -581,46 +587,25 @@ QStringList BuildManager::parseExtendedCommandLine(QString str, const QFileInfo
  */
 QString BuildManager::extractOutputRedirection(const QString &commandLine, QString &stdOut, QString &stdErr)
 {
-	static QRegExp rxStdOut("[^2]>\\s*(\\S+)");
-	static QRegExp rxStdErr("2>\\s*(\\S+)");
+	QStringList args = ::extractOutputRedirection(tokenizeCommandLine(commandLine), stdOut, stdErr);
+	if (stdOut.isEmpty() && stdErr.isEmpty()) {
+		return commandLine;
+	} else {
+		return args.join(" ");
+	}
+}
 
-	int stdErrStart = rxStdErr.indexIn(commandLine);
-	if (stdErrStart >= 0) {
-		stdErr = rxStdErr.cap(1);
-	}
-	int stdOutStart = rxStdOut.indexIn(commandLine);
-	if (stdOutStart >= 0) {
-		stdOutStart += 1;
-		stdOut = rxStdOut.cap(1);
-	}
-	return commandLine.left(indexMin(stdErrStart, stdOutStart)).trimmed();
+QString addPathDelimeter(const QString &a)
+{
+    return ((a.endsWith("/") || a.endsWith("\\")) ? a : (a + QDir::separator()));
 }
 
 QString BuildManager::findFileInPath(QString fileName)
 {
-	/*#ifdef Q_OS_MAC
-		QProcess *myProcess = new QProcess();
-		myProcess->start("bash -l -c \"echo $PATH\"");
-		myProcess->waitForFinished(3000);
-		if(myProcess->exitStatus()==QProcess::CrashExit) return "";
-		QByteArray res=myProcess->readAllStandardOutput();
-		delete myProcess;
-		QString path(res);
-	#else*/
-	QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
-	QString path = env.value("PATH");
-	if (path.isNull()) return "";
-//#endif
-#ifdef Q_OS_WIN32
-	if (!fileName.contains('.')) fileName += ".exe";
-	QStringList paths = path.split(";"); //windows
-#else
-	QStringList paths = path.split(":"); //linux
-#endif
-	foreach (const QString &p, paths)
-		if (p.endsWith("/") && QFileInfo(p + fileName).exists()) return (p + fileName);
-		else if (p.endsWith("\\") && QFileInfo(p + fileName).exists()) return (p + fileName);
-		else if (QFileInfo(p + "/" + fileName).exists()) return (p + "\\" + fileName);
+	foreach (QString path, getEnvironmentPathList()) {
+		path = addPathDelimeter(path);
+		if (QFileInfo(path + fileName).exists()) return (path + fileName);
+	}
 	return "";
 }
 
@@ -649,11 +634,6 @@ QString W32_FileAssociation(QString ext)
 	return result;
 }
 
-QString addPathDelimeter(const QString &a)
-{
-	return ((a.endsWith("/") || a.endsWith("\\")) ? a : (a + "\\"));
-}
-
 QStringList getProgramFilesPaths()
 {
 	QStringList res;
@@ -667,41 +647,116 @@ QStringList getProgramFilesPaths()
 	return res;
 }
 
-static QString miktexpath = "<search>";
-QString getMiKTeXBinPathReal()
-{
-	QSettings reg("HKEY_CURRENT_USER\\Software", QSettings::NativeFormat);
-	QString mikPath = reg.value("MiK/MikTeX/CurrentVersion/MiKTeX/Install Root", "").toString();
-	if (!mikPath.isEmpty())
-		return addPathDelimeter(mikPath) + "miktex\\bin\\";
-	foreach (const QString &d, getProgramFilesPaths())
-		foreach (const QString &p, QDir(d).entryList(QStringList(), QDir::AllDirs, QDir::Time))
-			if (p.toLower().contains("miktex") && QDir(d + addPathDelimeter(p) + "miktex\\bin\\").exists())
-				return d + addPathDelimeter(p) + "miktex\\bin\\";
-	static const QStringList candidates = QStringList() << "C:\\miktex\\miktex\\bin"
-														<< "C:\\tex\\texmf\\miktex\\bin"
-														<< "C:\\miktex\\bin"
-														<< QString(getenv("LOCALAPPDATA")) + "\\Programs\\MiKTeX 2.9\\miktex\\bin";
+/*!
+ * \return the Uninstall string of the program from the registry
+ *
+ * Note: This won't get the path of 64bit installations when TXS running as a 32bit app due to wow6432 regristry redirection
+ * http://www.qtcentre.org/threads/36966-QSettings-on-64bit-Machine
+ * http://stackoverflow.com/questions/25392251/qsettings-registry-and-redirect-on-regedit-64bit-wow6432
+ * No workaround known, except falling back to the native Windows API. For the moment we'll rely on alternative detection methods.
+ */
+QString getUninstallString(const QString &program) {
+	foreach (const QString &baseKey, QStringList() << "HKEY_LOCAL_MACHINE" << "HKEY_CURRENT_USER") {
+		QSettings base(baseKey, QSettings::NativeFormat);
+		QString s = base.value("Software\\Microsoft\\Windows\\CurrentVersion\\Uninstall\\" + program + "\\UninstallString").toString();
+		if (!s.isEmpty())
+			return s;
+	}
+	return QString();
+}
 
-	foreach (const QString &d, candidates)
-		if (QDir(d).exists())
-			return d + "\\";
+/*!
+ * \return an existing subdir of the from path\subDirFilter\subSubDir.
+ *
+ * Example:
+ * QStringList searchPaths = QStringList() << "C:\\" << "D:\\"
+ * findSubdir(searchPaths, "*miktex*", "miktex\\bin\\")
+ * will work for "C:\\MikTeX\\miktex\\bin\\" or "D:\\MikTeX 2.9\\miktex\\bin"
+ */
+QString findSubDir(const QStringList &searchPaths, const QString &subDirFilter, const QString &subSubDir) {
+	qDebug() << searchPaths;
+	foreach (const QString &path, searchPaths) {
+		foreach (const QString &dir, QDir(path).entryList(QStringList(subDirFilter), QDir::AllDirs, QDir::Time)) {
+			QDir fullPath(addPathDelimeter(path) + addPathDelimeter(dir) + subSubDir);
+			if (fullPath.exists())
+				return fullPath.absolutePath();
+		}
+	}
+	return QString();
+}
+
+/*!
+ * Returns the MikTeX bin path.
+ * This should not be called directly but only through getMiKTeXBinPath() to prevent multiple searches.
+ */
+QString getMiKTeXBinPathInternal()
+{
+	// search the registry
+	QString mikPath = getUninstallString("MiKTeX 2.9");
+	// Note: this does currently not work for MikTeX 64bit because of registry redirection (also we would have to parse the
+	// uninstall string there for the directory). For the moment we'll fall back to other detection methods.
+	if (!mikPath.isEmpty() && QDir(addPathDelimeter(mikPath) + "miktex\\bin\\").exists()) {
+		mikPath = addPathDelimeter(mikPath) + "miktex\\bin\\";
+	}
+
+	// search the PATH
+	if (mikPath.isEmpty()) {
+		foreach (QString path, getEnvironmentPathList()) {
+			path = addPathDelimeter(path);
+			if ((path.endsWith("\\miktex\\bin\\x64\\") || path.endsWith("\\miktex\\bin\\")) && QDir(path).exists())
+				return path;
+		 }
+	}
+
+	// search all program file paths
+	if (!mikPath.isEmpty()) {
+		mikPath = QDir::toNativeSeparators(findSubDir(getProgramFilesPaths(), "*miktex*", "miktex\\bin\\"));
+	}
+
+	// search a fixed list of additional locations
+	if (mikPath.isEmpty()) {
+		static const QStringList candidates = QStringList() << "C:\\miktex\\miktex\\bin"
+															<< "C:\\tex\\texmf\\miktex\\bin"
+															<< "C:\\miktex\\bin"
+															<< QString(qgetenv("LOCALAPPDATA")) + "\\Programs\\MiKTeX 2.9\\miktex\\bin";
+		foreach (const QString &path, candidates)
+			if (QDir(path).exists()) {
+				mikPath = path;
+				break;
+			}
+	}
+
+	// post-process to detect 64bit installation
+	if (!mikPath.isEmpty()) {
+		if (QDir(mikPath + "x64\\").exists())
+			return mikPath + "x64\\";
+		else
+			return mikPath;
+	}
 	return "";
 }
 
+static QString miktexBinPath = "<search>";
+/*!
+ * \return the MikTeX bin path. This uses caching so that the search is only performed once per session.
+ */
 QString getMiKTeXBinPath()
 {
-	if (miktexpath == "<search>") miktexpath = getMiKTeXBinPathReal();
-	return miktexpath;
+	if (miktexBinPath == "<search>") miktexBinPath = getMiKTeXBinPathInternal();
+	return miktexBinPath;
 }
 
-QString getTeXLiveBinPath()
+/*!
+ * Returns the TeXlive bin path.
+ * This should not be called directly but only through getTeXLiveWinBinPath() to prevent multiple searches.
+ */
+QString getTeXLiveWinBinPathInternal()
 {
 	//check for uninstall entry
 	foreach (const QString &baseKey, QStringList() << "HKEY_CURRENT_USER" << "HKEY_LOCAL_MACHINE") {
 		QSettings reg(baseKey + "\\Software", QSettings::NativeFormat);
 		QString uninstall;
-		for (int v = 2014; v > 2008; v--) {
+		for (int v = 2017; v > 2008; v--) {
 			uninstall = reg.value(QString("microsoft/windows/currentversion/uninstall/TeXLive%1/UninstallString").arg(v), "").toString();
 			if (!uninstall.isEmpty()) {
 				int p = uninstall.indexOf("\\tlpkg\\", 0, Qt::CaseInsensitive);
@@ -720,13 +775,23 @@ QString getTeXLiveBinPath()
 	return path + "\\bin\\win32\\";
 }
 
+static QString texliveWinBinPath = "<search>";
+/*!
+ * \return the TeXlive bin path on windows. This uses caching so that the search is only performed once per session.
+ */
+QString getTeXLiveWinBinPath()
+{
+	if (texliveWinBinPath == "<search>") texliveWinBinPath = getTeXLiveWinBinPathInternal();
+	return texliveWinBinPath;
+}
+
+
 QString findGhostscriptDLL()   //called dll, may also find an exe
 {
 	//registry
-	for (int type = 0; type <= 1; type++)
-		for (int pos = 0; pos <= 1; pos++) {
-			QString regBase = QString(pos == 0 ? "HKEY_CURRENT_USER" : "HKEY_LOCAL_MACHINE") + "\\Software\\" + QString(type == 0 ? "GPL" : "AFPL") + " Ghostscript";
-			QSettings reg(regBase, QSettings::NativeFormat);
+	foreach (QString program, QStringList() << "GPL Ghostscript" << "AFPL Ghostscript")
+		foreach(QString hkeyBase, QStringList() << "HKEY_CURRENT_USER" << "HKEY_LOCAL_MACHINE") {
+			QSettings reg(hkeyBase + "\\Software\\" + program, QSettings::NativeFormat);
 			QStringList version = reg.childGroups();
 			if (version.empty()) continue;
 			version.sort();
@@ -766,7 +831,7 @@ QString searchBaseCommand(const QString &cmd, QString options)
 			if (!mikPath.isEmpty() && QFileInfo(mikPath + fileName).exists())
 				return "\"" + mikPath + fileName + "\" " + options; //found
 			//Windows TeX Live
-			QString livePath = getTeXLiveBinPath();
+			QString livePath = getTeXLiveWinBinPath();
 			if (!livePath.isEmpty() && QFileInfo(livePath + fileName).exists())
 				return "\"" + livePath + fileName + "\" " + options; //found
 #endif
@@ -911,6 +976,13 @@ ExpandedCommands BuildManager::expandCommandLine(const QString &str, ExpandingOp
 
 			//recurse
 			ExpandedCommands ecNew = expandCommandLine(cmd, options);
+			if (ecNew.commands.length() > 1 && atomicCommands.contains(cmd)) {
+                txsWarning(QString(tr("The command %1 is expected to be atomic. However, it is currently "
+                                      "defined as a command-chain containing %2 commands. This is beyond "
+                                      "the specification and may lead to surprising side-effects.\n\n"
+									  "Please change your configuration and define command lists only at "
+									  "Options -> Build not at Options -> Commands.")).arg(cmd).arg(ecNew.commands.length()));
+			}
 			QList<CommandToRun> &newPart = ecNew.commands;
 
 			//clean up modifiers
@@ -1052,7 +1124,7 @@ QString getCommandLineViewPs()
 	if (!def.isEmpty())
 		return def;
 
-	QString livePath = getTeXLiveBinPath();
+	QString livePath = getTeXLiveWinBinPath();
 	if (!livePath.isEmpty())
 		if (QFileInfo(livePath + "psv.exe").exists())
 			return "\"" + livePath + "psv.exe\"  \"?am.ps\"";
@@ -1093,7 +1165,7 @@ QString getCommandLineViewPdfExternal()
 QString getCommandLineGhostscript()
 {
 	const QString gsArgs = " \"?am.ps\"";
-	QString livePath = getTeXLiveBinPath();
+	QString livePath = getTeXLiveWinBinPath();
 	if (!livePath.isEmpty()) {
 		if (QFileInfo(livePath + "rungs.exe").exists())
 			return "\"" + livePath + "rungs.exe\"" + gsArgs;
@@ -1169,7 +1241,7 @@ void BuildManager::registerOptions(ConfigManagerInterface &cmi)
 	cmi.registerOption("Tools/Quick Mode", &deprecatedQuickmode, -1);
 	cmi.registerOption("Tools/Max Expanding Nesting Deep", &maxExpandingNestingDeep, 10);
 	Q_ASSERT(sizeof(dvi2pngMode) == sizeof(int));
-	cmi.registerOption("Tools/Dvi2Png Mode", reinterpret_cast<int *>(&dvi2pngMode), -1);
+    cmi.registerOption("Tools/Dvi2Png Mode", reinterpret_cast<int *>(&dvi2pngMode), 3);
 	cmi.registerOption("Files/Save Files Before Compiling", reinterpret_cast<int *>(&saveFilesBeforeCompiling), (int)SFBC_ONLY_NAMED);
 	cmi.registerOption("Preview/Remove Beamer Class", &previewRemoveBeamer, true);
 	cmi.registerOption("Preview/Precompile Preamble", &previewPrecompilePreamble, true);
@@ -1313,7 +1385,7 @@ void BuildManager::readSettings(QSettings &settings)
 			settings.remove(QString("User/ToolName%1").arg(i));
 		}
 	}
-	int md = reinterpret_cast<int &>(dvi2pngMode);
+    int md = dvi2pngMode;
 #ifdef NO_POPPLER_PREVIEW
 	if (md == DPM_EMBEDDED_PDF)
 		md = -1;
@@ -1379,6 +1451,9 @@ void BuildManager::checkLatexConfiguration(bool &noWarnAgain)
 bool BuildManager::runCommand(const QString &unparsedCommandLine, const QFileInfo &mainFile, const QFileInfo &currentFile, int currentLine, QString *buffer, QTextCodec *codecForBuffer )
 {
 	if (waitingForProcess()) return false;
+
+    emit clearLogs();
+
 	if (unparsedCommandLine.isEmpty()) {
 		emit processNotification(tr("Error: No command given"));
 		return false;
@@ -1510,14 +1585,24 @@ void BuildManager::emitEndRunningSubCommandFromProcessX(int)
 }
 
 
-ProcessX *BuildManager::firstProcessOfDirectExpansion(const QString &command, const QFileInfo &mainFile, const QFileInfo &currentFile, int currentLine)
+ProcessX *BuildManager::firstProcessOfDirectExpansion(const QString &command, const QFileInfo &mainFile, const QFileInfo &currentFile, int currentLine,bool nonstop)
 {
 	ExpandingOptions options(mainFile, currentFile, currentLine);
+    if(nonstop){
+        options.nestingDeep=1; // tweak to avoid pop-up error messages
+    }
 	ExpandedCommands expansion = expandCommandLine(command, options);
 	if (options.canceled) return 0;
 
 	if (expansion.commands.isEmpty()) return 0;
 
+    foreach(CommandToRun elem,expansion.commands){
+        if(elem.command.isEmpty()){
+            return 0; // error in command expansion
+        }
+
+    }
+
 	return newProcessInternal(expansion.commands.first().command, mainFile);
 }
 
@@ -1835,6 +1920,31 @@ void BuildManager::setAllCommands(const CommandMapping &cmds, const QStringList
 	}
 }
 
+/*!
+ * Returns a best guess compiler for a string given in "% !TeX TS-program = [program]" \ "% !TeX program = [program]"
+ */
+QString BuildManager::guessCompilerFromProgramMagicComment(const QString &program)
+{
+	if (program == "latex") return BuildManager::CMD_LATEX;
+	else if (program == "pdflatex") return BuildManager::CMD_PDFLATEX;
+	else if (program == "xelatex") return BuildManager::CMD_XELATEX;
+	else if (program == "luatex" || program == "lualatex") return BuildManager::CMD_LUALATEX;
+	return QString();
+
+}
+
+/*!
+ * Returns a best guess viewer for a string given in "% !TeX TS-program = [program]" \ "% !TeX program = [program]"
+ */
+QString BuildManager::guessViewerFromProgramMagicComment(const QString &program)
+{
+	if (program == "latex") return BuildManager::CMD_VIEW_DVI;
+	else if (program == "pdflatex" || program == "xelatex" || program == "luatex" || program == "lualatex") {
+		return CMD_VIEW_PDF;
+	}
+	return QString();
+}
+
 void BuildManager::singleInstanceCompleted(int status)
 {
 	Q_UNUSED(status);
@@ -1865,7 +1975,7 @@ void BuildManager::latexPreviewCompleted(int status)
 		ProcessX *p1 = qobject_cast<ProcessX *> (sender());
 		if (!p1) return;
 		// dvi -> png
-		ProcessX *p2 = firstProcessOfDirectExpansion(CMD_DVIPNG, p1->getFile());
+        ProcessX *p2 = firstProcessOfDirectExpansion(CMD_DVIPNG, p1->getFile(),QFileInfo(),0,true);
 		if (!p2) return; //dvipng does not work
 		//REQUIRE(p2);
 		if (!p1->overrideEnvironment().isEmpty()) p2->setOverrideEnvironment(p1->overrideEnvironment());
@@ -1876,7 +1986,7 @@ void BuildManager::latexPreviewCompleted(int status)
 		ProcessX *p1 = qobject_cast<ProcessX *> (sender());
 		if (!p1) return;
 		// dvi -> ps
-		ProcessX *p2 = firstProcessOfDirectExpansion("txs:///dvips/[-E]", p1->getFile());
+        ProcessX *p2 = firstProcessOfDirectExpansion("txs:///dvips/[-E]", p1->getFile(),QFileInfo(),0,true);
 		if (!p2) return; //dvips does not work
 		//REQUIRE(p2);
 		if (!p1->overrideEnvironment().isEmpty()) p2->setOverrideEnvironment(p1->overrideEnvironment());
@@ -1907,8 +2017,8 @@ void BuildManager::dvi2psPreviewCompleted(int status)
 	if (!p2) return;
 	// ps -> png, ghostscript is quite, safe, will create 24-bit png
 	QString filePs = parseExtendedCommandLine("?am.ps", p2->getFile()).first();
-	ProcessX *p3 = firstProcessOfDirectExpansion("txs:///gs/[-q][-dSAFER][-dBATCH][-dNOPAUSE][-sDEVICE=png16m][-dEPSCrop][-sOutputFile=\"?am)1.png\"]", filePs);
-	REQUIRE(p3);
+    ProcessX *p3 = firstProcessOfDirectExpansion("txs:///gs/[-q][-dSAFER][-dBATCH][-dNOPAUSE][-sDEVICE=png16m][-dEPSCrop][-sOutputFile=\"?am)1.png\"]", filePs,QFileInfo(),0,true);
+    if (!p3) return; //gs does not work
 	if (!p2->overrideEnvironment().isEmpty()) p3->setOverrideEnvironment(p2->overrideEnvironment());
 	connect(p3, SIGNAL(finished(int)), this, SLOT(conversionPreviewCompleted(int)));
 	p3->startCommand();
