@@ -38,13 +38,14 @@ public:
 	~ConfigManager();
 
 	QString iniPath();
-	bool isUsbMode();
+	static QString portableConfigDir();
+	bool isPortableMode();
 
 	QSettings *newQSettings();
 	QSettings *readSettings(bool reread = false);
 	QSettings *saveSettings(const QString &saveName = "");
 
-	bool execConfigDialog(QWidget *parentToDialog);
+    bool execConfigDialog(QWidget *parentToDialog);
 
 //public configuration
 
@@ -81,7 +82,6 @@ public:
 	int guiSecondaryToolbarIconSize;
 	bool useTexmakerPalette;
 	int interfaceFontSize;
-	bool newLeftPanelLayout;
 	bool mruDocumentChooser;
 	bool configShowAdvancedOptions, configRiddled;
 	bool centralVisible;
@@ -131,6 +131,7 @@ public:
 	int tabstop;
 
 	bool useEscForClosingLog;
+	bool showShortcutsInTooltips;
 	int replaceQuotes; //0: none, 1: ``..'', 2: \"< \"> 3: \"`..\"' , 4: \\og..\\fg{} 5: \"> \"<
 
 	// table autoformat
@@ -200,28 +201,32 @@ public:
 	bool insertUTF;
 
 	//menus
-	QObject *menuParent; //lets assume there is only one
+    QObjectList menuParents;
+    QObject *menuParent; //lets assume there is only one
 	QMenuBar *menuParentsBar; //that's ugly, but faster as long as there is only one (both values could be extracted from the action's name)
 	QList<QMenu *> managedMenus;
 	QHash<QString, QKeySequence> managedMenuShortcuts;
 	QList<QPair<QString, QString> > managedMenuNewShortcuts;
-#if (QT_VERSION > 0x050000) && (defined(Q_OS_MAC))
+#if (QT_VERSION > 0x050000) && (QT_VERSION <= 0x050700) && (defined(Q_OS_MAC))
 	//workaround that osx/qt does not support alt+key/esc as shortcuts
-	QMap<QKeySequence, QAction *> specialShortcuts;
+    QMultiMap<QKeySequence, QAction *> specialShortcuts;
 #endif
 
 	QMenu *newManagedMenu(const QString &id, const QString &text);
 	QMenu *newManagedMenu(QMenu *menu, const QString &id, const QString &text);
+    QMenu *newManagedMenu(QWidget *menuParent,QMenuBar *menuParentsBar,const QString &id, const QString &text);
 	QAction *newManagedAction(QWidget *menu, const QString &id, const QString &text, const char *slotName, const QList<QKeySequence> &shortCuts = QList<QKeySequence>(), const QString &iconFile = "");
+    QAction *newManagedAction(QObject *rootMenu,QWidget *menu, const QString &id, const QString &text, QObject *obj,const char *slotName, const QList<QKeySequence> &shortCuts = QList<QKeySequence>(), const QString &iconFile = "");
 	QAction *newManagedAction(QWidget *menu, const QString &id, QAction *act);
 	QAction *newOrLostOldManagedAction(QWidget *menu, const QString &id, const QString &text, const char *slotName, const QList<QKeySequence> &shortCuts = QList<QKeySequence>(), const QString &iconFile = "");
 	QAction *getManagedAction(const QString &id);
+    QList<QAction *> getManagedActions(const QString &id);
 	QList<QAction *> getManagedActions(const QStringList &ids, const QString &commonPrefix = "");
 	QMenu *getManagedMenu(const QString &id);
 	void removeManagedMenus();
 	void triggerManagedAction(const QString &id);
 
-	static QString iniFileOverride;
+	static QString configDirOverride;
     static bool dontRestoreSession;
 private:
 	void setupDirectoryStructure();
@@ -231,7 +236,7 @@ private:
 	void modifyMenuContent(QStringList &ids, const QString &id);
 public:
 	void modifyMenuContents();
-	void modifyManagedShortcuts();
+    void modifyManagedShortcuts(QString startsWith="");
 	void setManagedShortCut(QAction *act, int num, const QKeySequence &key);
 	void loadManagedMenu(QMenu *parent, const QDomElement &f);
 	void loadManagedMenus(const QString &f);
@@ -252,7 +257,6 @@ public:
 	void populateCustomActions(QListWidget *parent, QMenu *menu, bool go = false);
 
 signals:
-	void newLeftPanelLayoutChanged(bool newValue);
 	void watchedMenuChanged(const QString &menuId);
 	void iconSizeChanged(int value);
 	void secondaryIconSizeChanged(int value);
@@ -325,9 +329,9 @@ private slots:
 	void moveDownCommand();
 	void moveCommand(int dir, int atRow = -1);
 
-	void latexTreeItemChanged(QTreeWidgetItem *item, int l);
-	void latexTreeNewItem(bool menu = false);
-	void latexTreeNewMenuItem();
+	void menuTreeItemChanged(QTreeWidgetItem *item, int l);
+	void menuTreeNewItem(bool menu = false);
+	void menuTreeNewMenuItem();
 	void toggleVisibleTreeItems(bool show);
 	void activateInternalViewer(bool activated);
 
