@@ -170,7 +170,7 @@ private:
 
 	QPoint m_point;
 
-	static int environmentFormat, referencePresentFormat, referenceMissingFormat, referenceMultipleFormat, citationMissingFormat, citationPresentFormat, structureFormat,
+	static int environmentFormat, referencePresentFormat, referenceMissingFormat, referenceMultipleFormat, citationMissingFormat, citationPresentFormat, structureFormat, todoFormat,
 	       packagePresentFormat, packageMissingFormat, packageUndefinedFormat,
 	       wordRepetitionFormat, wordRepetitionLongRangeFormat, badWordFormat, grammarMistakeFormat, grammarMistakeSpecial1Format, grammarMistakeSpecial2Format, grammarMistakeSpecial3Format, grammarMistakeSpecial4Format,
 	       numbersFormat, verbatimFormat, commentFormat, pictureFormat, pweaveDelimiterFormat, pweaveBlockFormat, sweaveDelimiterFormat, sweaveBlockFormat, math_DelimiterFormat, math_KeywordFormat,
@@ -236,7 +236,7 @@ public slots:
 	Q_INVOKABLE void zoomOut();
 	Q_INVOKABLE void resetZoom();
 
-	void mayNeedToOpenCompleter();
+    void mayNeedToOpenCompleter(bool fromSingleChar=false);
 	void documentContentChanged(int linenr, int count);
 
 private slots:
