@@ -19,6 +19,7 @@ public:
 	int showlinemultiples;
 	int cursorSurroundLines;
 	bool boldCursor;
+	bool centerDocumentInEditor;
 	bool folding, showlinestate, showcursorstate, realtimeChecking;
 	bool inlineSpellChecking, inlineCitationChecking, inlineReferenceChecking, inlineSyntaxChecking, inlineGrammarChecking, inlinePackageChecking;
 	bool inlineCheckNonTeXFiles;
@@ -42,16 +43,21 @@ public:
 	bool imageToolTip;
 	int maxImageTooltipWidth;
 	bool texdocHelpInInternalViewer;
+	bool monitorFilesForExternalChanges;
 	bool silentReload;
+	bool useQSaveFile;
 
 	bool autoInsertLRM, visualColumnMode, switchLanguagesDirection, switchLanguagesMath;
 
 	bool overwriteOpeningBracketFollowedByPlaceholder;
 	bool overwriteClosingBracketFollowingPlaceholder;
 	bool doubleClickSelectionIncludeLeadingBackslash;
+	int tripleClickSelectionIndex;
 	int contextMenuSpellcheckingEntryLocation;
 	int contextMenuKeyboardModifiers;  // actually this is a Qt::KeyboardModifiers flag (but we don't want to import the whole qt namespace here)
 
+    QString regExpTodoComment;
+
 	void settingsChanged();
 
 private:
