@@ -1,4 +1,6 @@
 #include "latexstyleparser.h"
+#include "latexparser/latexparser.h"
+#include "smallUsefulFunctions.h"
 
 LatexStyleParser::LatexStyleParser(QObject *parent, QString baseDirName, QString kpsecmd) :
 	SafeThread(parent)
@@ -69,12 +71,14 @@ void LatexStyleParser::run()
 
 		QStringList results, parsedPackages;
 		results = readPackage(fullName, parsedPackages); // parse package(s)
+		results = results.toSet().toList();  // remove duplicates
 		results.sort();
 
 		if (texdefMode) {
 			QStringList appendList;
 			//QStringList texdefResults=readPackageTexDef(fn); // parse package(s) by texdef as well for indirectly defined commands
 			QStringList texdefResults = readPackageTracing(fn);
+			texdefResults = texdefResults.toSet().toList();  // remove duplicates
 			texdefResults.sort();
 			// add only additional commands to results
 			if ( !results.isEmpty() && !texdefResults.isEmpty()) {
@@ -204,13 +208,13 @@ QStringList LatexStyleParser::parseLine(const QString &line, bool &inRequirePack
 	static const QRegExp rxComNoBrace("\\\\(newcommand|providecommand|DeclareRobustCommand)\\*?\\s*(\\\\\\w+)\\s*\\[?(\\d+)?\\]?(?:\\s*\\[([^\\]]+)\\])?");
 	static const QRegExp rxEnv("\\\\newenvironment\\s*\\{(\\w+)\\}\\s*\\[?(\\d+)?\\]?");
 	static const QRegExp rxInput("\\\\input\\s*\\{?([\\w._]+)");
-	static QRegExp rxRequire("\\\\RequirePackage\\s*\\{(\\S+)\\}");
+    static QRegExp rxRequire("\\\\(RequirePackage|RequirePackageWithOptions)\\s*\\{(\\S+)\\}");
 	rxRequire.setMinimal(true);
-	static const QRegExp rxRequireStart("\\\\RequirePackage\\s*\\{(.+)");
+    static const QRegExp rxRequireStart("\\\\(RequirePackage|RequirePackageWithOptions)\\s*\\{(.+)");
 	static const QRegExp rxDecMathSym("\\\\DeclareMathSymbol\\s*\\{\\\\(\\w+)\\}");
 	static const QRegExp rxNewLength("\\\\newlength\\s*\\{\\\\(\\w+)\\}");
 	static const QRegExp rxNewCounter("\\\\newcounter\\s*\\{(\\w+)\\}");
-	static const QRegExp rxLoadClass("\\\\LoadClass\\s*\\{(\\w+)\\}");
+    static const QRegExp rxLoadClass("\\\\(LoadClass|LoadClassWithOptions)\\s*\\{(\\w+)\\}");
 	QStringList results;
 	if (line.startsWith("\\endinput"))
 		return results;
@@ -243,7 +247,7 @@ QStringList LatexStyleParser::parseLine(const QString &line, bool &inRequirePack
 				break;
 			optionCount++;
 		}
-		qDebug() << line << rxDef.capturedTexts() << optionCount;
+        //qDebug() << line << rxDef.capturedTexts() << optionCount;
 		name += makeArgString(optionCount) + "#S";
 		if (!results.contains(name))
 			results << name;
@@ -339,7 +343,7 @@ QStringList LatexStyleParser::parseLine(const QString &line, bool &inRequirePack
 		return results;
 	}
 	if (rxRequire.indexIn(line) > -1) {
-		QString arg = rxRequire.cap(1);
+        QString arg = rxRequire.cap(2);
 		foreach (QString elem, arg.split(',')) {
 			QString package = elem.remove(' ');
 			if (!package.isEmpty())
@@ -348,16 +352,21 @@ QStringList LatexStyleParser::parseLine(const QString &line, bool &inRequirePack
 		return results;
 	}
 	if (rxRequireStart.indexIn(line) > -1) {
-		QString arg = rxRequireStart.cap(1);
+        QString arg = rxRequireStart.cap(2);
+		int requireEnd = arg.indexOf('}');
+		if (requireEnd >= 0) {
+			arg = arg.left(requireEnd);
+		} else {
+			inRequirePackage = true;
+		}
 		foreach (QString elem, arg.split(',')) {
 			QString package = elem.remove(' ');
 			if (!package.isEmpty())
 				results << "#include:" + package;
 		}
-		inRequirePackage = true;
 	}
 	if (rxLoadClass.indexIn(line) > -1) {
-		QString arg = rxLoadClass.cap(1);
+        QString arg = rxLoadClass.cap(2);
 		if (!arg.isEmpty()) {
 			if (mPackageAliases.contains(arg))
 				foreach (QString elem, mPackageAliases.values(arg)) {
