@@ -79,7 +79,9 @@ void TexstudioApp::init(QStringList &cmdLine)
 
 	if (!delayedFileLoad.isEmpty()) cmdLine << delayedFileLoad;
 	mw->executeCommandLine(cmdLine, true);
-	mw->startupCompleted();
+    if(!cmdLine.contains("--auto-tests")){
+        mw->startupCompleted();
+    }
 }
 
 TexstudioApp::~TexstudioApp()
@@ -127,8 +129,12 @@ QStringList parseArguments(const QStringList &args, bool &outStartAlways)
 				cmdLine << "--page" << args[i];
 			else if ((cmdArgument == "-insert-cite" || cmdArgument == "--insert-cite") && (++i < args.count()))
 				cmdLine << "--insert-cite" << args[i];
-			else if (cmdArgument == "--ini-file" && (++i < args.count()))
-				ConfigManager::iniFileOverride = args[i];
+			else if (cmdArgument == "--ini-file" && (++i < args.count())) {
+				// deprecated: use --config instead
+				ConfigManager::configDirOverride = QFileInfo(args[i]).absolutePath();
+			}
+			else if (cmdArgument == "--config" && (++i < args.count()))
+				ConfigManager::configDirOverride = args[i];
 			else if (cmdArgument.startsWith("-"))
 				cmdLine << cmdArgument;
 		} else
@@ -143,14 +149,15 @@ bool handleCommandLineOnly(const QStringList &cmdLine) {
 		QTextStream(stdout) << "Usage: texstudio [options] [file]\n"
 							<< "\n"
 							<< "Options:\n"
-							<< "  --ini-file FILE         use the specified config file\n"
+							<< "  --config DIR            use the specified settings directory\n"
 							<< "  --master                define the document as explicit root document\n"
 							<< "  --line LINE[:COL]       position the cursor at line LINE and column COL\n"
 							<< "  --insert-cite CITATION  inserts the given citation\n"
 							<< "  --start-always          start a new instance, even if TXS is already running\n"
 							<< "  --pdf-viewer-only       run as a standalone pdf viewer without an editor\n"
 							<< "  --page PAGENUM          display a certain page in the pdf viewer\n"
-							<< "  --no-session            do not load/save the session at startup/close\n";
+                            << "  --no-session            do not load/save the session at startup/close\n"
+                            << "  --version               show version number\n";
 		return true;
 	}
 
