@@ -181,6 +181,10 @@ public:
 			return m_width;
 		}
 
+		int leftMarginAndPadding() const {
+			return m_leftMargin + m_leftPadding;
+		}
+
 		QHash<QDocumentLineHandle*, QPair<int, int> > getStatus(){
 		    return m_status;
 		}
@@ -246,19 +250,21 @@ public:
 		
 		bool m_constrained;
 		bool m_hardLineWrap,m_lineWidthConstraint;
+		int m_leftMargin;
 		int m_width, m_height;
 		
 		int m_tabStop;
 		static int m_defaultTabStop;
 
 		static double m_lineSpacingFactor;
+		static bool m_centerDocumentInEditor;
 
         static QFont *m_baseFont;  // original font associated with the document
         static QFont *m_font;      // current font, pointSize = m_baseFont.pointSize + m_fontSizeModifier
         static int m_fontSizeModifier;
 		static bool m_fixedPitch;
 		static QDocument::WorkAroundMode m_workArounds;
-		static int m_leftMargin;
+		static int m_leftPadding;  // width between left edge of the document and start of the text
 		static QDocument::WhiteSpaceMode m_showSpaces;
 		static QDocument::LineEnding m_defaultLineEnding;
 		static QTextCodec* m_defaultCodec;
