@@ -710,6 +710,14 @@ QDocumentCursor QDocumentCursor::selectionEnd() const
 	return m_handle ? m_handle->selectionEnd() : QDocumentCursor();
 }
 
+/*!
+	\return A cursor pointing at the position of the anchor.
+*/
+QDocumentCursor QDocumentCursor::anchorCursor() const
+{
+	return m_handle ? m_handle->anchorCursor() : QDocumentCursor();
+}
+
 /*!
 	\return The selected text
 */
@@ -876,6 +884,14 @@ bool QDocumentCursor::hasSelection() const
 	return m_handle ? m_handle->hasSelection() : false;
 }
 
+/*!
+ * \return true if there is an selection and the anchor is before the cursor
+ */
+bool QDocumentCursor::isForwardSelection() const
+{
+	return m_handle ? m_handle->isForwardSelection() : false;
+}
+
 /*!
 	\brief clear the selection
 */
@@ -886,6 +902,14 @@ void QDocumentCursor::clearSelection()
 	
 }
 
+/*!
+ * \brief exchanges cursor and anchor positions
+ */
+void QDocumentCursor::flipSelection() {
+	if ( m_handle )
+		m_handle->flipSelection();
+}
+
 /*!
 	\brief Select something
 */
@@ -896,6 +920,15 @@ void QDocumentCursor::select(SelectionType t)
 	
 }
 
+/*!
+	\brief Expand a current selection
+*/
+void QDocumentCursor::expandSelect(QDocumentCursor::SelectionType t)
+{
+	if ( m_handle )
+		m_handle->expandSelect(t);
+}
+
 /*!
 	\brief Set the selection boundary
 	
