@@ -109,10 +109,10 @@ public:
 		void addOverlayNoLock(const QFormatRange& over);
 		void removeOverlay(const QFormatRange& over);
 		bool hasOverlay(int id);
-		QList<QFormatRange> getOverlays(int preferredFormat);
-		QFormatRange getOverlayAt(int index, int preferredFormat);
-		QFormatRange getFirstOverlayBetween(int start, int end, int preferredFormat = -1);
-		QFormatRange getLastOverlayBetween(int start, int end, int preferredFormat = -1);
+		QList<QFormatRange> getOverlays(int preferredFormat) const;
+		QFormatRange getOverlayAt(int index, int preferredFormat) const;
+		QFormatRange getFirstOverlay(int start = 0, int end = -1, int preferredFormat = -1) const;
+		QFormatRange getLastOverlay(int start = 0, int end = -1, int preferredFormat = -1) const;
 		
 		void shiftOverlays(int position, int offset);
 		
