@@ -84,7 +84,7 @@ static void setFormatOption(QFormat& fmt, const QString& field, const QString& v
 	\brief Constructor
 */
 QFormatScheme::QFormatScheme(QObject *p)
- : QObject(p)
+ : QObject(p),modified(false)
 {
 	setFormat("normal", QFormat());
 }
@@ -451,7 +451,7 @@ QString QFormatScheme::id(int ifid) const
 }
 
 /*!
-	\return The integer format id associated to format key \a fid
+	\return The integer format id associated to format key \a sfid
 */
 int QFormatScheme::id(const QString& sfid) const
 {
@@ -460,6 +460,14 @@ int QFormatScheme::id(const QString& sfid) const
 	return (idx == -1) ? 0 : idx;
 }
 
+/*!
+ * \return true if the format key \a sfid is valid
+ */
+bool QFormatScheme::exists(const QString& sfid) const
+{
+	return m_formatKeys.contains(sfid);
+}
+
 /*!
 	\return The text format associated with format key \a fid
 	
