@@ -1,6 +1,8 @@
 #include "syntaxcheck.h"
 #include "latexdocument.h"
 #include "tablemanipulation.h"
+#include "latexparser/latexreader.h"
+
 /*! \class SyntaxCheck
  *
  * asynchrnous thread which checks latex syntax of the text lines
@@ -291,8 +293,6 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                 }// ignore mismatching mathstop commands
 				continue;
 			}
-			if (ltxCommands->possibleCommands["user"].contains(word) || ltxCommands->customCommands.contains(word))
-				continue;
 
 			//tabular checking
 			if (topEnv("tabular", activeEnv) != 0) {
@@ -348,6 +348,10 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 			if (word.contains('@'))
 				continue;
 
+            // don't highlight custom commands
+            if (ltxCommands->possibleCommands["user"].contains(word) || ltxCommands->customCommands.contains(word))
+                continue;
+
 			if (!checkCommand(word, activeEnv)) {
 				Error elem;
 				elem.range = QPair<int, int>(wordstart, word.length());
@@ -487,7 +491,7 @@ QString SyntaxCheck::getErrorAt(QDocumentLineHandle *dlh, int pos, StackEnvironm
 
 	QStringList messages;
 	messages << tr("no error") << tr("unrecognized command") << tr("unrecognized math command") << tr("unrecognized tabular command") << tr("tabular command outside tabular env") << tr("math command outside math env") << tr("tabbing command outside tabbing env") << tr("more cols in tabular than specified") << tr("cols in tabular missing")
-	         << tr("\\\\ missing") << tr("closing environment which has not been opened") << tr("environment not closed") << tr("unrecognized key in key option") << tr("unrecognized value in key option");
+             << tr("\\\\ missing") << tr("closing environment which has not been opened") << tr("environment not closed") << tr("unrecognized key in key option") << tr("unrecognized value in key option") << tr("command outside suitable env");
 	return messages.value(int(result), tr("unknown"));
 }
 /*!
@@ -650,7 +654,7 @@ void SyntaxCheck::markUnclosedEnv(Environment env)
 bool SyntaxCheck::stackContainsDefinition(const TokenStack &stack) const
 {
 	for (int i = 0; i < stack.size(); i++) {
-		if (stack[i].subtype == Tokens::definition)
+		if (stack[i].subtype == Token::definition)
 			return true;
 	}
 	return false;
@@ -676,12 +680,12 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 
 	// check command-words
 	for (int i = 0; i < tl.length(); i++) {
-		Tokens tk = tl.at(i);
+		Token tk = tl.at(i);
 		// ignore commands in definition arguments e.g. \newcommand{cmd}{definition}
 		if (stackContainsDefinition(stack)) {
-			Tokens top = stack.top();
+			Token top = stack.top();
 			if (top.dlh != tk.dlh) {
-				if (tk.type == Tokens::closeBrace) {
+				if (tk.type == Token::closeBrace) {
 					stack.pop();
 				} else
 					continue;
@@ -692,11 +696,11 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 					stack.pop();
 			}
 		}
-		if (tk.subtype == Tokens::definition && (tk.type == Tokens::braces || tk.type == Tokens::openBrace)) {
+		if (tk.subtype == Token::definition && (tk.type == Token::braces || tk.type == Token::openBrace)) {
 			stack.push(tk);
 			continue;
 		}
-        if (tk.type == Tokens::punctuation || tk.type == Tokens::symbol) {
+        if (tk.type == Token::punctuation || tk.type == Token::symbol) {
             QString word = line.mid(tk.start, tk.length);
             QStringList forbiddenSymbols;
             forbiddenSymbols<<"^"<<"_";
@@ -707,13 +711,11 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
                 newRanges.append(elem);
             }
         }
-		if (tk.type == Tokens::commandUnknown) {
+		if (tk.type == Token::commandUnknown) {
 			QString word = line.mid(tk.start, tk.length);
 			if (word.contains('@')) {
 				continue; //ignore commands containg @
 			}
-			if (ltxCommands->possibleCommands["user"].contains(word) || ltxCommands->customCommands.contains(word))
-				continue;
 			if (ltxCommands->mathStartCommands.contains(word) && (activeEnv.isEmpty() || activeEnv.top().name != "math")) {
 				Environment env;
 				env.name = "math";
@@ -749,6 +751,8 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 				activeEnv.top().excessCol = 0;
 				continue;
 			}
+            if (ltxCommands->possibleCommands["user"].contains(word) || ltxCommands->customCommands.contains(word))
+                continue;
 			if (!checkCommand(word, activeEnv)) {
 				Error elem;
 				elem.range = QPair<int, int>(tk.start, tk.length);
@@ -757,7 +761,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 				continue;
 			}
 		}
-		if (tk.type == Tokens::env) {
+		if (tk.type == Token::env) {
 			QString env = line.mid(tk.start, tk.length);
 			// corresponds \end{env}
 			if (!activeEnv.isEmpty()) {
@@ -789,7 +793,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 			}
 		}
 
-		if (tk.type == Tokens::beginEnv) {
+		if (tk.type == Token::beginEnv) {
 			QString env = line.mid(tk.start, tk.length);
 			// corresponds \begin{env}
 			Environment tp;
@@ -805,24 +809,24 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 				QString option;
 				if ((env == "tabu") || (env == "longtabu")) { // special treatment as the env is rather not latex standard
 					for (int k = i + 1; k < tl.length(); k++) {
-						Tokens elem = tl.at(k);
-						if (elem.level < tk.level - 1)
+						Token elem = tl.at(k);
+                        if (elem.level < tk.level-1)
 							break;
-						if (elem.level >= tk.level)
+                        if (elem.level > tk.level)
 							continue;
-						if (elem.type == Tokens::braces) { // take the first mandatory argument at the correct level -> TODO: put colDef also for tabu correctly in lexer
+						if (elem.type == Token::braces) { // take the first mandatory argument at the correct level -> TODO: put colDef also for tabu correctly in lexer
 							option = line.mid(elem.start + 1, elem.length - 2); // strip {}
 						}
 					}
 				} else {
 
 					for (int k = i + 1; k < tl.length(); k++) {
-						Tokens elem = tl.at(k);
-						if (elem.level < tk.level - 1)
+						Token elem = tl.at(k);
+                        if (elem.level < tk.level)
 							break;
-						if (elem.level >= tk.level)
+                        if (elem.level > tk.level)
 							continue;
-						if (elem.subtype == Tokens::colDef) {
+						if (elem.subtype == Token::colDef) {
 							option = line.mid(elem.start + 1, elem.length - 2); // strip {}
 							break;
 						}
@@ -836,19 +840,16 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 		}
 
 
-		if (tk.type == Tokens::command) {
+		if (tk.type == Token::command) {
 			QString word = line.mid(tk.start, tk.length);
 
 			if (word == "\\begin" || word == "\\end") {
 				// check complete expression e.g. \begin{something}
-				if (tl.length() > i + 1 && tl.at(i + 1).type == Tokens::braces) {
+				if (tl.length() > i + 1 && tl.at(i + 1).type == Token::braces) {
 					word = word + line.mid(tl.at(i + 1).start, tl.at(i + 1).length);
 				}
 			}
 
-			if (ltxCommands->possibleCommands["user"].contains(word) || ltxCommands->customCommands.contains(word))
-				continue;
-
 			if (ltxCommands->mathStartCommands.contains(word) && (activeEnv.isEmpty() || activeEnv.top().name != "math")) {
 				Environment env;
 				env.name = "math";
@@ -921,6 +922,9 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 
 			}
 
+            if (ltxCommands->possibleCommands["user"].contains(word) || ltxCommands->customCommands.contains(word))
+                continue;
+
 			if (!checkCommand(word, activeEnv)) {
 				Error elem;
 				elem.range = QPair<int, int>(tk.start, tk.length);
@@ -932,12 +936,28 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 					elem.type = ERR_TabularCommandOutsideTab;
 				if (ltxCommands->possibleCommands["tabbing"].contains(word))
 					elem.type = ERR_TabbingCommandOutside;
+                if(elem.type== ERR_unrecognizedCommand){
+                    // try to find command in unspecified envs
+                    QStringList keys=ltxCommands->possibleCommands.keys();
+                    keys.removeAll("math");
+                    keys.removeAll("tabular");
+                    keys.removeAll("tabbing");
+                    keys.removeAll("normal");
+                    foreach (QString key, keys) {
+                        if(key.contains("%"))
+                            continue;
+                        if(ltxCommands->possibleCommands[key].contains(word)){
+                            elem.type = ERR_commandOutsideEnv;
+                            break;
+                        }
+                    }
+                }
 				newRanges.append(elem);
 			}
 		}
-        if (tk.type == Tokens::specialArg) {
+        if (tk.type == Token::specialArg) {
 			QString value = line.mid(tk.start, tk.length);
-			QString special = ltxCommands->mapSpecialArgs.value(int(tk.type - Tokens::specialArg));
+			QString special = ltxCommands->mapSpecialArgs.value(int(tk.type - Token::specialArg));
 			if (!ltxCommands->possibleCommands[special].contains(value)) {
 				Error elem;
 				elem.range = QPair<int, int>(tk.start, tk.length);
@@ -945,7 +965,7 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 				newRanges.append(elem);
 			}
         }
-		if (tk.type == Tokens::keyVal_key) {
+		if (tk.type == Token::keyVal_key) {
 			// special treatment for key val checking
 			QString command = tk.optionalCommandName;
 			QString value = line.mid(tk.start, tk.length);
@@ -960,12 +980,12 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 					// now find mandatory argument
 					QString subcommand;
 					for (int k = i + 1; k < tl.length(); k++) {
-						Tokens tk_elem = tl.at(k);
-						if (tk_elem.level > tk.level - 1)
+						Token tk_elem = tl.at(k);
+                        if (tk_elem.level > tk.level)
 							continue;
-						if (tk_elem.level < tk.level - 1)
+                        if (tk_elem.level < tk.level)
 							break;
-						if (tk_elem.type == Tokens::braces) {
+						if (tk_elem.type == Token::braces) {
 							subcommand = line.mid(tk_elem.start + 1, tk_elem.length - 2);
 							if (elem == "key%" + command + "/" + subcommand) {
 								break;
@@ -1008,18 +1028,18 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 				}
 			}
 		}
-		if (tk.subtype == Tokens::keyVal_val) {
+		if (tk.subtype == Token::keyVal_val) {
 			//figure out keyval
 			QString word = line.mid(tk.start, tk.length);
 			// first get command
-			Tokens cmd = getCommandTokenFromToken(tl, tk);
+			Token cmd = getCommandTokenFromToken(tl, tk);
 			QString command = line.mid(cmd.start, cmd.length);
 			// figure out key
 			QString key;
 			for (int k = i - 1; k >= 0; k--) {
-				Tokens elem = tl.at(k);
+				Token elem = tl.at(k);
 				if (elem.level == tk.level - 1) {
-					if (elem.type == Tokens::keyVal_key) {
+					if (elem.type == Token::keyVal_key) {
 						key = line.mid(elem.start, elem.length);
 					}
 					break;
@@ -1035,12 +1055,12 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 					// now find mandatory argument
 					QString subcommand;
 					for (int k = i + 1; k < tl.length(); k++) {
-						Tokens tk_elem = tl.at(k);
+						Token tk_elem = tl.at(k);
 						if (tk_elem.level > tk.level - 2)
 							continue;
 						if (tk_elem.level < tk.level - 2)
 							break;
-						if (tk_elem.type == Tokens::braces) {
+						if (tk_elem.type == Token::braces) {
 							subcommand = line.mid(tk_elem.start + 1, tk_elem.length - 2);
 							if (elem == "key%" + command + "/" + subcommand) {
 								break;
@@ -1075,6 +1095,9 @@ void SyntaxCheck::checkLine(const QString &line, Ranges &newRanges, StackEnviron
 						break;
 				}
 				if (iterator != lst.end() && !options.isEmpty()) {
+                    if(options.startsWith("#")){
+                        continue; // ignore type keys, like width#L
+                    }
 					QStringList l = options.split(",");
 					if (!l.contains(word)) {
 						Error elem;
