@@ -12,18 +12,20 @@
 #include "tabbingdialog.h"
 
 TabbingDialog::TabbingDialog(QWidget *parent, const char *name)
-		: QDialog(parent) {
+	: QDialog(parent)
+{
 	setWindowTitle(name);
 	setModal(true);
 	ui.setupUi(this);
 
 	ui.spinBoxColumns->setValue(2);
-	ui.spinBoxColumns->setRange(2,99);
+	ui.spinBoxColumns->setRange(2, 99);
 
 	ui.spinBoxRows->setValue(1);
-	ui.spinBoxRows->setRange(1,99);
+	ui.spinBoxRows->setRange(1, 99);
 	setWindowTitle(tr("Quick Tabbing"));
 }
 
-TabbingDialog::~TabbingDialog() {
+TabbingDialog::~TabbingDialog()
+{
 }
