@@ -2,10 +2,12 @@
 #include "qdocumentcursor.h"
 #include "qdocumentline.h"
 #include "smallUsefulFunctions.h"
+#include "latexparser/latexparser.h"
 #include "scriptengine.h"
 #include "configmanager.h"
 
-QStringList LatexTables::tabularNames = QStringList() << "tabular" << "array" << "longtable" << "supertabular" << "tabu" << "longtabu";
+QStringList LatexTables::tabularNames = QStringList() << "tabular" << "array" << "longtable" << "supertabular" << "tabu" << "longtabu"
+                                        << "IEEEeqnarray" << "xtabular" << "xtabular*" << "mpxtabular" << "mpxtabular*";
 QStringList LatexTables::tabularNamesWithOneOption = QStringList() << "tabular*" << "tabularx" << "tabulary";
 QStringList LatexTables::mathTables = QStringList() << "align" << "align*" << "array" << "matrix" << "matrix*" << "bmatrix" << "bmatrix*"
                                       << "Bmatrix" << "Bmatrix*" << "pmatrix" << "pmatrix*" << "vmatrix" << "vmatrix*"
@@ -940,7 +942,7 @@ LatexTableLine *LatexTableModel::parseNextLine(const QString &text, int &startCo
 	int endCol = findRowBreak(text, startCol);
 	if (endCol < 0) {
 		line = text.mid(startCol).trimmed();
-		endCol = text.length();
+        //endCol = text.length();
 	} else {
 		line = text.mid(startCol, endCol - startCol).trimmed();
 		endCol += 2; // now behind "\\"
@@ -976,12 +978,15 @@ LatexTableLine *LatexTableModel::parseNextLine(const QString &text, int &startCo
 		}
 	}
 
-	startCol = endCol;
-
 	LatexTableLine *ltl = new LatexTableLine(this);
 	if (!pre.isEmpty()) ltl->setMetaLine(pre);
-	if (!line.isEmpty()) ltl->setColLine(line);
+    if (!line.isEmpty() || endCol>startCol) ltl->setColLine(line); // allow empty columns
 	if (!lineBreakOption.isEmpty()) ltl->setLineBreakOption(lineBreakOption);
+
+    startCol = endCol;
+    if(startCol<0)
+        startCol=text.length();
+
 	return ltl;
 }
 
@@ -1122,10 +1127,12 @@ QStringList LatexTableModel::getAlignedLines(const QStringList alignment, const
 
 	}
 	if (!ret.isEmpty()) {
-		// no break at final line, except for cases like "\\ \hline"
+        // no break at final line, except for cases like "\\ \hline" and empty column
 		QString &last = ret.last();
 		if (last.endsWith("\\\\")) {
-			last = trimRight(last.left(last.length() - 2));
+            QString zw=trimRight(last.left(last.length() - 2));
+            if(!zw.isEmpty())
+                last = zw;
 		}
 	}
 
@@ -1153,7 +1160,7 @@ void LatexTableLine::setColLine(const QString line)
 			if (i < line.length()) start = i + 1;
 		}
 	}
-	if (start < line.length()) appendCol(line.mid(start));
+    if (start <= line.length()) appendCol(line.mid(start));
 }
 
 QString LatexTableLine::colText(int col, int width, const QChar &alignment)
