@@ -613,6 +613,18 @@ void QDocumentCursorTest::movePosition_data(){
 	QTest::newRow("right across line") << text << 0 << 8 << 3 << (int)QDocumentCursor::Right << 1 << 1 << true;
 	QTest::newRow("right across multi line") << text << 0 << 8 << 13 << (int)QDocumentCursor::Right << 2 << 1 << true;
 	QTest::newRow("right across empty line") << "0123 5678\n\n0123 5678" << 0 << 8 << 4 << (int)QDocumentCursor::Right << 2 << 1 << true;
+
+	QTest::newRow("StartOfParenthesis no parens") << "012 456" << 0 << 4 << 1 << (int)QDocumentCursor::StartOfParenthesis << 0 << 4 << false;
+	QTest::newRow("StartOfParenthesis4") << "012 {567} 0" << 0 << 4 << 1 << (int)QDocumentCursor::StartOfParenthesis << 0 << 4 << true;
+	QTest::newRow("StartOfParenthesis5") << "012 {567} 0" << 0 << 5 << 1 << (int)QDocumentCursor::StartOfParenthesis << 0 << 4 << true;
+	QTest::newRow("StartOfParenthesis6") << "012 {567} 0" << 0 << 6 << 1 << (int)QDocumentCursor::StartOfParenthesis << 0 << 4 << true;
+	QTest::newRow("StartOfParenthesis7") << "012 {567} 0" << 0 << 7 << 1 << (int)QDocumentCursor::StartOfParenthesis << 0 << 4 << true;
+	QTest::newRow("StartOfParenthesis8") << "012 {567} 0" << 0 << 8 << 1 << (int)QDocumentCursor::StartOfParenthesis << 0 << 4 << true;
+	QTest::newRow("StartOfParenthesis9") << "012 {567} 0" << 0 << 9 << 1 << (int)QDocumentCursor::StartOfParenthesis << 0 << 4 << true;
+	QTest::newRow("StartOfParenthesis10") << "012 {567} 0" << 0 << 10 << 1 << (int)QDocumentCursor::StartOfParenthesis << 0 << 10 << false;
+
+	QTest::newRow("StartOfParenthesis nested same") << "012 {456 {901} 456}" << 0 << 15 << 1 << (int)QDocumentCursor::StartOfParenthesis << 0 << 4 << true;
+	QTest::newRow("StartOfParenthesis nested other") << "012 {456 [901] 456}" << 0 << 15 << 1 << (int)QDocumentCursor::StartOfParenthesis << 0 << 4 << true;
 }
 void QDocumentCursorTest::movePosition(){
 	QFETCH(QString, text);
@@ -646,7 +658,7 @@ void QDocumentCursorTest::bidiMoving_data(){
 	const int L = (int)QDocumentCursor::Left;
 	const int R = (int)QDocumentCursor::Right;
 
-	QString withMarkers = QString::fromUtf8("\n" "ه‎\\glqq{}‎‎" "\n"); //rendered as \glqq{}o
+    QString withMarkers = QString::fromUtf8("\n" "ه‎\\glqq{}‎‎" "\n"); //rendered as \glqq{}o
 	QTest::newRow("with all markers 1")  << withMarkers << 1<<0  << 1 << R << 2<<0;
 	QTest::newRow("with all markers 2")  << withMarkers << 1<<0  << 1 << L << 1<<11; //????? that is not the same position as if run manually (there it skips 11 and goes to 10)
 	QTest::newRow("with all markers 2b") << withMarkers << 1<<11 << 1 << L << 1<<10;
@@ -698,6 +710,11 @@ void QDocumentCursorTest::bidiMoving(){
 	QFETCH(int, newLine);
 	QFETCH(int, newColumn);
 
+    if (m_autoTests){
+        qDebug("skipped bidi tests");
+        return;
+    }
+
 #if QT_VERSION >= 0x040800
 
 	doc->setText(text,false);
