@@ -2,6 +2,8 @@
 #include "testmanager.h"
 //hel 
 #include "smallUsefulFunctions_t.h"
+#include "latexparser_t.h"
+#include "encoding_t.h"
 #include "buildmanager_t.h"
 #include "codesnippet_t.h"
 #include "qdocumentcursor_t.h"
@@ -18,6 +20,7 @@
 #include "tablemanipulation_t.h"
 #include "syntaxcheck_t.h"
 #include "updatechecker_t.h"
+#include "utilsui_t.h"
 #include "utilsversion_t.h"
 #include "help_t.h"
 #include "latexoutputfilter_t.h"
@@ -67,11 +70,13 @@ QString TestManager::execute(TestLevel level, LatexEditorView* edView, QCodeEdit
 	QString tr;
 	QList<QObject*> tests=QList<QObject*>()
         << new SmallUsefulFunctionsTest()
+        << new LatexParserTest()
+        << new EncodingTest()
         << new LatexOutputFilterTest()
 		<< new BuildManagerTest(buildManager)
 		<< new CodeSnippetTest(editor)
 		<< new QDocumentLineTest()
-		<< new QDocumentCursorTest()
+        << new QDocumentCursorTest(level==TL_AUTO)
 		<< new QDocumentSearchTest(editor,level==TL_ALL)
 		<< new QSearchReplacePanelTest(codeedit,level==TL_ALL)
 		<< new QEditorTest(editor,level==TL_ALL)
@@ -84,6 +89,7 @@ QString TestManager::execute(TestLevel level, LatexEditorView* edView, QCodeEdit
 		<< new TableManipulationTest(editor)
 		<< new SyntaxCheckTest(edView)
 		<< new UpdateCheckerTest(level==TL_ALL)
+		<< new UtilsUITest(level==TL_ALL)
         << new VersionTest(level==TL_ALL)
         << new HelpTest();
 	bool allPassed=true;
