@@ -91,7 +91,7 @@ public:
 
 public slots:
 	LatexEditorView *load(const QString &f , bool asProject = false, bool hidden = false, bool recheck = true, bool dontAsk = false);
-	void executeCommandLine(const QStringList &args, bool realCmdLine);
+    void executeCommandLine(const QStringList &args, bool realCmdLine);
 	void hideSplash(); ///< hide splash screen
 	void startupCompleted();
 	void onOtherInstanceMessage(const QString &);  ///< For messages for the single instance
@@ -123,7 +123,7 @@ private slots:
 	void updateToolBarMenu(const QString &menuName);
 	void showTestProgress(const QString &message);
 private:
-	void executeTests(const QStringList &args); ///< execute self-tests. Only works for debug-builds.
+    bool executeTests(const QStringList &args); ///< execute self-tests. Only works for debug-builds.
 	void generateAddtionalTranslations();
 	void setupMenus();
 	void setupDockWidgets();
@@ -150,11 +150,13 @@ private:
 
 	//gui
 	Editors *editors;
+	QSplitter *sidePanelSplitter;
 	QSplitter *mainHSplitter;
 	QSplitter *centralVSplitter;
 	QFrame *centralFrame;
 	QToolBar *centralToolBar;
 	CustomWidgetList *leftPanel;
+	TitledPanel *sidePanel;
 	SymbolGridWidget *MostUsedSymbolWidget, *FavoriteSymbolWidget;
 	QString hiddenLeftPanelWidgets;
 
@@ -250,6 +252,7 @@ protected slots:
 	void fileClose(); ///< close current editor
 	void fileCloseAll(); ///< close all open editors
 	void fileExit(); ///< exit application
+    void fileExitWithError(); ///< exit application with error code, used for auto-tests
 private:
 	void centerFileSelector();
 protected slots:
@@ -372,6 +375,8 @@ protected slots:
 
 	void moveCursorTodlh();
 
+    void LTErrorMessage(QString message);
+
 private slots:
 	void readSettings(bool reread = false); ///< read configured/default settings from ini
 	void saveSettings(const QString &configName = ""); ///< save all setting to ini
@@ -437,6 +442,8 @@ protected slots:
 	void updateStatusBarEncoding();
 	void addMagicRoot();
 	void addMagicCoding();
+    void addMagicBibliography();
+    void addMagicProgram();
 
 	void quickTabular(); ///< start quick tabular wizard
 	void quickArray(); ///< start quick array wizard
@@ -471,6 +478,7 @@ private slots:
 	bool runCommand(const QString &commandline, QString *buffer = 0, QTextCodec *codecForBuffer = 0);
 protected slots:
 	void processNotification(const QString &message);
+    void clearLogs();
 	void openTerminal(); ///< open external terminal
 	void cleanAll();
 	void checkShortcutChangeNotification(QAction *act);
@@ -483,6 +491,7 @@ protected slots:
 	void generateRandomText();
 
 	bool loadLog();
+	void onCompileError();
 	void setLogMarksVisible(bool visible);
 	void clearLogEntriesInEditors();
 	void updateLogEntriesInEditors();
@@ -518,7 +527,6 @@ protected slots:
 	void showStatusbar();
 	void viewCloseSomething();
 	void setFullScreenMode();
-	void viewAlignWindows();
 	void viewSetHighlighting(QAction *act);
 	void showHighlightingMenu();
 
@@ -543,6 +551,7 @@ protected slots:
 	void gotoLine(int line, int col = 0, LatexEditorView *edView = 0, QEditor::MoveFlags mflags = QEditor::Navigation, bool setFocus = true); // line is 0 based
 	bool gotoLine(int line, const QString &fileName);  // line is 0 based, absolute file name
 	void gotoLogEntryEditorOnly(int logEntryNumber);
+	QDocumentCursor getLogEntryContextCursor(const QDocumentLineHandle *dlh, const LatexLogEntry &entry);
 	bool gotoLogEntryAt(int newLineNumber);
 	bool gotoMark(bool backward, int id = -1);
 	QList<int> findOccurencesApproximate(QString checkLine, const QString &guessedWord);
@@ -602,6 +611,7 @@ protected slots:
 	void moveDocumentToEnd();
 
 	void updateTexQNFA();
+	void updateTexLikeQNFA(QString languageName, QString filename);
 	void updateHighlighting();
 
 	void toggleGrammar(int type);
@@ -620,7 +630,7 @@ protected:
 	void dropEvent(QDropEvent *event);
 	virtual void changeEvent(QEvent *e);
 	virtual void resizeEvent(QResizeEvent *e);
-#if (QT_VERSION > 0x050000) && (defined(Q_OS_MAC))
+#if (QT_VERSION > 0x050000) && (QT_VERSION <= 0x050700) && (defined(Q_OS_MAC))
 	bool eventFilter(QObject *obj, QEvent *event);
 #endif
 
@@ -665,6 +675,7 @@ protected:
 	void restoreBookmarks(LatexEditorView *edView);
 
 	bool completerPreview;
+    QPixmapCache previewCache;
 
 	bool recheckLabels;
 
@@ -693,6 +704,7 @@ public slots:
 	void iamalive();
 	void checkLatexInstall();
 	void checkCWLs();
+    void checkLanguageTool();
 
 	void slowOperationStarted();
 	void slowOperationEnded();
