@@ -149,6 +149,7 @@ OutputViewWidget::OutputViewWidget(QWidget *parent) :
 	setSelectorStyle(TabSelector);
 	mToggleViewAction->setText(tr("Messages / Log File"));
 	mToggleViewAction->setIcon(getRealIcon("logpanel"));
+	setFrameStyle(NoFrame);
 
 
 	// messages
@@ -270,12 +271,25 @@ void OutputViewWidget::changeEvent(QEvent *event)
 
 Q_DECLARE_METATYPE(QAction *)
 
-CustomWidgetList::CustomWidgetList(QWidget *p):
-	QDockWidget(p), newStyle(false), toolbox(0), frame(0), stack(0), toolbar(0)
+CustomWidgetList::CustomWidgetList(QWidget *parent):
+	QWidget(parent), stack(0), toolbar(0)
 {
-	toggleViewAction()->setIcon(getRealIcon("sidebar"));
 	setContextMenuPolicy(Qt::CustomContextMenu);
 	connect(this, SIGNAL(customContextMenuRequested(QPoint)), this, SLOT(customContextMenuRequested(QPoint)));
+
+	QHBoxLayout *hlayout = new QHBoxLayout(this);
+	hlayout->setSpacing(0);
+	hlayout->setMargin(0);
+
+	toolbar = new QToolBar("LogToolBar", this);
+	toolbar->setFloatable(false);
+	toolbar->setOrientation(Qt::Vertical);
+	toolbar->setMovable(false);
+	hlayout->addWidget(toolbar);
+
+	stack = new QStackedWidget(this);
+	stack->setFrameShape(QFrame::NoFrame);
+	hlayout->addWidget(stack);
 }
 
 void CustomWidgetList::addWidget(QWidget *widget, const QString &id, const QString &text, const QString &iconName)
@@ -285,6 +299,8 @@ void CustomWidgetList::addWidget(QWidget *widget, const QString &id, const QStri
 	widget->setProperty("Name", text);
 	widget->setProperty("iconName", iconName);
 	widget->setProperty("StructPos", widgets.size());
+	QFrame *asFrame = qobject_cast<QFrame *>(widget);
+	if (asFrame) asFrame->setFrameShape(QFrame::NoFrame);
 
 	QAction *Act = new QAction(text, this);
 	Act->setCheckable(true);
@@ -303,8 +319,7 @@ void CustomWidgetList::setWidgetText(QWidget *widget, const QString &text)
 	int pos = widgets.indexOf(widget);
 	if (pos < 0) return;
 	widget->setProperty("Name", text);
-	if (newStyle) actions()[pos]->setToolTip(text);
-	else toolbox->setItemText(pos, text);
+	actions()[pos]->setToolTip(text);
 }
 
 void CustomWidgetList::setWidgetIcon(const QString &id, const QString &icon)
@@ -325,15 +340,9 @@ void CustomWidgetList::showPageFromAction()
 	if (!act) return;
 	QWidget *wid = widget(act->data().toString());
 	stack->setCurrentWidget(wid);
-	setWindowTitle(act->toolTip());
 	foreach (QAction *a, toolbar->actions())
 		a->setChecked(a == act);
-}
-
-void CustomWidgetList::currentWidgetChanged(int i)
-{
-	Q_ASSERT(newStyle == false);
-	setWindowTitle(toolbox->itemText(i));
+	emit titleChanged(act->toolTip());
 }
 
 void CustomWidgetList::toggleWidgetFromAction(bool on)
@@ -344,7 +353,7 @@ void CustomWidgetList::toggleWidgetFromAction(bool on)
 		hiddenWidgetsIds.removeAll(act->data().toString());
 	else if (!hiddenWidgetsIds.contains(act->data().toString()))
 		hiddenWidgetsIds.append(act->data().toString());
-	showWidgets(newStyle);
+	showWidgets();
 }
 
 void CustomWidgetList::customContextMenuRequested(const QPoint &localPosition)
@@ -359,74 +368,32 @@ void CustomWidgetList::customContextMenuRequested(const QPoint &localPosition)
 	}
 }
 
-void CustomWidgetList::showWidgets(bool newLayoutStyle)
+void CustomWidgetList::showWidgets()
 {
-	if (toolbox) {
-		for (int i = 0; i < widgets.count(); i++) {
-			toolbox->removeItem(toolbox->indexOf(widgets[i]));
-			widgets[i]->setParent(this);//otherwise it will be deleted
-		}
-		delete toolbox;
+	setToolbarIconSize(ConfigManagerInterface::getInstance()->getOption("GUI/SecondaryToobarIconSize").toInt());
+
+	// TODO: is this still needed when there is no need to switch between old and new style
+	for (int i = 0; i < widgets.count(); i++) {
+		stack->removeWidget(widgets[i]);
+		widgets[i]->setParent(this); //otherwise it will be deleted
 	}
-	if (stack) {
-		for (int i = 0; i < widgets.count(); i++) {
-			stack->removeWidget(widgets[i]);
-			widgets[i]->setParent(this);//otherwise it will be deleted
-		}
-		delete stack;
+
+	foreach(QAction *act, toolbar->actions()) {
+		toolbar->removeAction(act);
 	}
-	if (toolbar) delete toolbar;
-	if (frame) delete frame;
-	newStyle = newLayoutStyle;
-	if (newLayoutStyle) {
-		toolbox = 0;
-		frame = new QFrame(this);
-		frame->setLineWidth(0);
-		frame->setFrameShape(QFrame::Box);
-		frame->setFrameShadow(QFrame::Plain);
+	for (int i = 0; i < widgets.size(); i++)
+		if (!hiddenWidgetsIds.contains(widgetId(widgets[i]))) {
+			stack->addWidget(widgets[i]);
+			QAction *act = toolbar->addAction(QIcon(widgets[i]->property("iconName").toString()), widgets[i]->property("Name").toString());
+			act->setCheckable(true);
+			if (i == 0) act->setChecked(true);
+			act->setData(widgetId(widgets[i]));
+			connect(act, SIGNAL(triggered()), this, SLOT(showPageFromAction()));
+			widgets[i]->setProperty("associatedAction", QVariant::fromValue<QAction *>(act));
+		} else widgets[i]->hide();
 
-		toolbar = new QToolBar("LogToolBar", this);
-		toolbar->setFloatable(false);
-		toolbar->setOrientation(Qt::Vertical);
-		toolbar->setMovable(false);
-
-		setToolbarIconSize(ConfigManagerInterface::getInstance()->getOption("GUI/SecondaryToobarIconSize").toInt());
-
-		stack = new QStackedWidget(this);
-
-		for (int i = 0; i < widgets.size(); i++)
-			if (!hiddenWidgetsIds.contains(widgetId(widgets[i]))) {
-				stack->addWidget(widgets[i]);
-				QAction *act = toolbar->addAction(QIcon(widgets[i]->property("iconName").toString()), widgets[i]->property("Name").toString());
-				act->setCheckable(true);
-				if (i == 0) act->setChecked(true);
-				act->setData(widgetId(widgets[i]));
-				connect(act, SIGNAL(triggered()), this, SLOT(showPageFromAction()));
-				widgets[i]->setProperty("associatedAction", QVariant::fromValue<QAction *>(act));
-			} else widgets[i]->hide();
-
-		QHBoxLayout *hlayout = new QHBoxLayout(frame);
-		hlayout->setSpacing(0);
-		hlayout->setMargin(0);
-		hlayout->addWidget(toolbar);
-		hlayout->addWidget(stack);
-
-		setWidget(frame);
-	} else {
-		frame = 0;
-		toolbar = 0;
-		stack = 0;
-		toolbox = new QToolBox(this);
-		for (int i = 0; i < widgets.size(); i++)
-			if (!hiddenWidgetsIds.contains(widgetId(widgets[i]))) {
-				toolbox->addItem(widgets[i], QIcon(widgets[i]->property("iconName").toString()), widgets[i]->property("Name").toString());
-			} else widgets[i]->hide();
-		connect(toolbox, SIGNAL(currentChanged(int)), SLOT(currentWidgetChanged(int)));
-		setWidget(toolbox);
-
-	}
 	if (!widgets.empty()) //name after active (first) widget
-		setWindowTitle(widgets.first()->property("Name").toString());
+		emit titleChanged(widgets.first()->property("Name").toString());
 }
 
 void CustomWidgetList::setToolbarIconSize(int sz)
@@ -478,24 +445,15 @@ QList<QWidget *> CustomWidgetList::getWidgets() const
 
 void CustomWidgetList::setCurrentWidget(QWidget *widget)
 {
-	if (newStyle) {
-		stack->setCurrentWidget(widget);
-		QAction *act = widget->property("associatedAction").value<QAction *>();
-		foreach (QAction *a, toolbar->actions())
-			a->setChecked(a == act);
-	} else {
-		toolbox->setCurrentWidget(widget);
-	}
-}
-QWidget *CustomWidgetList::currentWidget() const
-{
-	if (newStyle) return stack->currentWidget();
-	else return toolbox->currentWidget();
+	stack->setCurrentWidget(widget);
+	QAction *act = widget->property("associatedAction").value<QAction *>();
+	foreach (QAction *a, toolbar->actions())
+		a->setChecked(a == act);
 }
 
-bool CustomWidgetList::isNewLayoutStyleEnabled() const
+QWidget *CustomWidgetList::currentWidget() const
 {
-	return newStyle;
+	return stack->currentWidget();
 }
 
 QString CustomWidgetList::widgetId(QWidget *widget) const
