@@ -550,41 +550,14 @@ QString msgGraphicalShellAction()
 #endif
 }
 
-QString getTerminalCommand()
-{
-#ifdef Q_OS_WIN
-	QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
-	QString windir = env.value("WINDIR", "c:/windows");
-	return windir + "/system32/cmd.exe";
-#elif defined(Q_OS_MAC)
-	QString command = "open /Applications/Utilities/Terminal.app/";
-	return command;
-#else // Linux
-	// Linux does not have a uniform way to determine the default terminal application
-	// gnome
-	QString command = execCommand("gsettings get org.gnome.desktop.default-applications.terminal exec");
-	command = command.replace('\'', "");
-	if (!command.isEmpty()) {
-		return command;
-	}
-	// fallback
-	QStringList fallbacks = QStringList() << "konsole" << "xterm";
-	foreach (const QString &fallback, fallbacks) {
-		QString command = execCommand("which " + fallback);
-		if (!command.isEmpty()) {
-			return command;
-		}
-	}
-	return QString();
-#endif
-}
-
 int x11desktop_env()
 {
-	// 0 : no kde ; 3: kde ; 4 : kde4 ;
+	// 0 : no kde ; 3: kde ; 4 : kde4 ; 5 : kde5 ;
 	QString kdesession = ::getenv("KDE_FULL_SESSION");
 	QString kdeversion = ::getenv("KDE_SESSION_VERSION");
-	if (!kdeversion.isEmpty()) return 4;
+	if (!kdeversion.isEmpty()) {
+		return kdeversion.toInt();
+	}
 	if (!kdesession.isEmpty()) return 3;
 	return 0;
 }
