@@ -61,7 +61,7 @@ void updatePathSettings(QProcess *proc, QString additionalPaths);
 void showInGraphicalShell(QWidget *parent, const QString &pathIn);
 QString msgGraphicalShellAction();
 
-QString getTerminalCommand();
+bool startTerminalEmulator(const QString &workingDir);
 
 //returns kde version 0,3,4
 int x11desktop_env();
