@@ -181,6 +181,24 @@ QColor colorFromRGBAstr(const QString &hex, QColor fallback)
 	return fallback;
 }
 
+/*!
+  Return a color with a more medium value. The amount of change is determined by factor. I.e. for a factor > 100
+  a dark color becomes lighter, a light color becomes darker. The reverse is true for factors < 100;
+  This is a generalization of QColor.lighter()/darker() which should provide a reasonable change in dark as well
+  as light contexts.
+ */
+QColor mediumLightColor(QColor color, int factor) {
+	if (color.value() == 0) {  // special handling for black because lighter() does not work there [QTBUG-9343].
+		factor = qMax(0, factor - 100);
+		return QColor(factor, factor, factor);  // i.e. QColor(50, 50, 50) for factor 150
+	}
+	if (color.value() < 128) {
+		return color.lighter(factor);
+	} else {
+		return color.darker(factor);
+	}
+}
+
 /*!
  * return the window to which an object belongs or the given fallback widget
  * Note: the signature is intentionally for a gerneric QObject, so that we can
@@ -203,3 +221,72 @@ QWidget *windowForObject(QObject *obj, QWidget *fallback)
 	}
 	return fallback;
 }
+
+
+/*!
+  interal
+  guesses a descriptive text from a text suited for a menu entry
+  This is copied from the internal function qt_strippedText() in qaction.cpp
+ */
+static QString strippedActionText(QString s) {
+	s.remove( QString::fromLatin1("...") );
+	for (int i = 0; i < s.size(); ++i) {
+		if (s.at(i) == QLatin1Char('&'))
+		s.remove(i, 1);
+	}
+	return s.trimmed();
+}
+
+/*!
+  interal
+  Adds possible shortcut information to the tooltip of the action.
+  This provides consistent behavior both with default and custom tooltips
+  when used in combination with removeShortcutToToolTip()
+ */
+void addShortcutToToolTip(QAction *action)
+{
+	if (!action->shortcut().isEmpty()) {
+		QString tooltip = action->property("tooltipBackup").toString();
+		if (tooltip.isEmpty()) {
+			tooltip = action->toolTip();
+			if (tooltip != strippedActionText(action->text())) {
+				action->setProperty("tooltipBackup", action->toolTip());  // action uses a custom tooltip. Backup so that we can restore it later.
+			}
+		}
+		QColor shortcutTextColor = QApplication::palette().color(QPalette::ToolTipText);
+		QString shortCutTextColorName;
+		if (shortcutTextColor.value() == 0) {
+			shortCutTextColorName = "gray";  // special handling for black because lighter() does not work there [QTBUG-9343].
+		} else {
+			int factor = (shortcutTextColor.value() < 128) ? 150 : 50;
+			shortCutTextColorName = shortcutTextColor.lighter(factor).name();
+		}
+		action->setToolTip(QString("<p style='white-space:pre'>%1&nbsp;&nbsp;<code style='color:%2; font-size:small'>%3</code></p>")
+		                   .arg(tooltip, shortCutTextColorName, action->shortcut().toString(QKeySequence::NativeText)));
+	}
+}
+
+/*!
+  interal
+  Removes possible shortcut information from the tooltip of the action.
+  This provides consistent behavior both with default and custom tooltips
+  when used in combination with addShortcutToToolTip()
+ */
+void removeShortcutFromToolTip(QAction *action)
+{
+	action->setToolTip(action->property("tooltipBackup").toString());
+	action->setProperty("tooltipBackup", QVariant());
+}
+
+/*!
+  Adds or removes shortcut information from the tooltip of the action.
+  This provides consistent behavior both with default and custom tooltips.
+ */
+void updateToolTipWithShortcut(QAction *action, bool showShortcut) {
+	if (showShortcut) {
+		addShortcutToToolTip(action);
+	} else {
+		removeShortcutFromToolTip(action);
+	}
+}
+
